Module platform

Module platform 

Functions

durable_sync
rename_with_retry
resolve_symlinks
Resolve symlinks to their canonical target path. Atomic operations should operate on the real file, not the symlink entry.
sync_dir
Fsync a directory to ensure metadata (directory entries) is persisted. This is important after rename operations to ensure durability. On Windows, this is a no-op since NTFS journals directory metadata.