pub fn get_comment_style(
path: &Path,
_mode: &str,
config: Option<&ToggleConfig>,
) -> Result<CommentStyle>Expand description
Get the comment style for a file based on its extension. If a config is provided, language-specific overrides take priority, then global overrides, then the hardcoded defaults.